/*
 * PDM - Pixil display manager
 *
 * Copyright (C) 2003, Penguru Consulting, LLC
 * Written by:  Jordan Crouse (jordan@penguru.net)
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

#ifndef PDM_H_
#define PDM_H_

#include <pwd.h>
#include <sys/types.h>

typedef struct {
  void *handle;
  int (*doauth)(uid_t *);
} authplugin_t;

#define FLAG_AUTH 0x01
#define FLAG_CAL  0x02

typedef struct {
  char *server;        /* The GUI server to start */
  int argc;
  char **argv;

  unsigned char flags;
  authplugin_t * authplugin; /* A holder for the auth plugin (if it is used) */

  /* Auth=no options */

  struct passwd *user;      /* The static user data is stored here */
  char *session;            /* The static session to use is stored here */

  struct {
    char *bin;              /* Calibration binary */
    int argc;
    char **argv;            /* Calibration args */
  } cal;

} dminfo_t;

const char *GET_PDM_DIR(void);
void SET_PDM_DIR(const char *);

int read_config(char *, dminfo_t *);

authplugin_t * load_auth_plugin(char *name);

#endif

