/*
 * PDM - Pixil display manager
 *
 * Copyright (C) 2003, Penguru Consulting, LLC
 * Written by:  Jordan Crouse (jordan@penguru.net)
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

#include <stdio.h>
#include <stdlib.h>
#include <unistd.h>
#include <dlfcn.h>
#include "pdm.h"

authplugin_t * load_auth_plugin(char *name) {

  char path[256];
  authplugin_t *plugin;

  if (!name) return 0;

  /* If an absolute path was passed, then use that, otherwise go
     for the defaults 
  */
  
  if (*name != '/') 
     snprintf(path, sizeof(path) - 1, "%s/plugins/%s.so",  GET_PDM_DIR(), name);
   else
     snprintf(path, sizeof(path) - 1,  "%s.so", name);

   if (access(path, R_OK | X_OK)) return 0;

   plugin = (authplugin_t *) calloc(sizeof(authplugin_t), 1);
   if (!plugin) return 0;

   plugin->handle = dlopen(path, RTLD_GLOBAL | RTLD_NOW);

   if (!plugin->handle) {
     free(plugin);
     return 0;
   }

   plugin->doauth = (int (*)(uid_t *))  dlsym(plugin->handle, "plugin_doauth");

   if (!plugin->doauth) {
     dlclose(plugin->handle);
     free(plugin);
     return 0;
   }

   return plugin;
}

